
/* win.cc */

#include "win.h"

#include "QAction"
#include "QPushButton"
#include "QSplitter"

#include <QApplication>

#include <QTableView>
#include <QTreeWidget>

#include "QSqlDatabase"
#include "QSqlQuery"
#include "QSqlRecord"
#include "QSqlTableModel"

/* ---------------------------------------------------------------------- */

void database (MyWin * win)
{
   QTableView * table = new QTableView (win);

   QTreeWidget * tree = new QTreeWidget (win);

   QTextEdit * info = new QTextEdit (win);

   QSplitter * vsplitter = new QSplitter (win);
   vsplitter->setOrientation (Qt::Vertical);
   vsplitter->addWidget (table);
   vsplitter->addWidget (info);

   QSplitter * hsplitter = new QSplitter (win);
   hsplitter->addWidget (tree);
   hsplitter->addWidget (vsplitter);

   QSqlDatabase db = QSqlDatabase::addDatabase("QSQLITE");
   db.setDatabaseName (":memory:");
   // db.setDatabaseName ("test.sqlite");
   db.open ();

   QSqlQuery query1 = db.exec ("CREATE TABLE colors (name TEXT, red INTEGER, green INTEGER, blue INTEGER)");

   db.exec ("INSERT INTO colors (name, red, green, blue) VALUES (\"blue\", 0, 0, 255)");

   QSqlQuery insert (db);
   insert.prepare ("INSERT INTO colors (name, red, green, blue) VALUES (:name, :red, :green, :blue)");
   insert.bindValue (":name", "green");
   insert.bindValue (":red", QVariant::fromValue (0));
   insert.bindValue (":green", QVariant::fromValue (255));
   insert.bindValue (":blue", QVariant::fromValue (0));
   insert.exec ();

   QSqlTableModel * model = new QSqlTableModel (win, db);
   model->setTable ("colors");
   model->select ();
   table->setModel (model);

   QStringList list = db.tables();
   info->append ("tables: " + list.join (","));

   for (int i = 0; i < list.size(); i++)
   {
       QString id = list[i];
       QSqlQuery query = db.exec ("SELECT * FROM " + id);

       QTreeWidgetItem * item = new QTreeWidgetItem;
       item->setText (0, id);
       tree->addTopLevelItem (item);

       QSqlRecord rec = query.record();
       for (int k = 0; k < rec.count (); k++)
       {
          QTreeWidgetItem * subitem = new QTreeWidgetItem;
          subitem->setText (0, rec.fieldName (k));
          item->addChild (subitem);
       }
   }

   win->tab->addTab (hsplitter, "database");
}

/* ---------------------------------------------------------------------- */

MyWin::MyWin (QWidget* parent) :
   QMainWindow (parent),
   mainMenu (NULL),
   statusBar (NULL),
   tab (NULL),
   fileMenu (NULL),
   editMenu (NULL),
   viewMenu (NULL)
{
   setup ();
}

/* ---------------------------------------------------------------------- */

void MyWin::setup ()
{
   mainMenu = new QMenuBar (this);
   // toolbar = new QToolBar (this);
   statusBar = new QStatusBar (this);

   /* tab widget */

   tab = new QTabWidget (this);
  tab->setTabPosition (QTabWidget::South);

   /* menu, toolbar, statusbar */

   this->setMenuBar (mainMenu);
   // this->addToolBar (toolbar);
   this->setCentralWidget (tab);
   this->setStatusBar (statusBar);

   /* actions */

   QAction * quit = new QAction (this);
   quit->setText ("&Quit");
   quit->setShortcut (Qt::CTRL + Qt::Key_Q);
   QObject::connect (quit, SIGNAL(triggered()), this, SLOT(close()));

   /* menu */

   fileMenu = mainMenu->addMenu ("&File");
   fileMenu->addAction (quit);

   viewMenu = mainMenu->addMenu ("&View");

   editMenu = mainMenu->addMenu ("&Edit");

   /* database */

   database (this);
}

/* ---------------------------------------------------------------------- */

// #include "win.moc"

/* ---------------------------------------------------------------------- */

extern "C" int main (int argc, char * * argv)
{
    QApplication app (argc, argv);
    app.setApplicationName ("qview");

    MyWin * win = new MyWin ();
    win->show ();

    return app.exec();
}

/* ---------------------------------------------------------------------- */

